@@ -11,17 +11,18 @@ import warnings
 import re
 import numpy as np
 
-import pandas.lib as lib
-from pandas.types.missing import isnull
-from pandas.types.dtypes import DatetimeTZDtype
-from pandas.types.common import (is_list_like, is_dict_like,
-                                 is_datetime64tz_dtype)
+import pandas._libs.lib as lib
+from pandas.core.dtypes.missing import isna
+from pandas.core.dtypes.dtypes import DatetimeTZDtype
+from pandas.core.dtypes.common import (
+    is_list_like, is_dict_like,
+    is_datetime64tz_dtype)
 
 from pandas.compat import (map, zip, raise_with_traceback,
                            string_types, text_type)
 from pandas.core.api import DataFrame, Series
 from pandas.core.base import PandasObject
-from pandas.tseries.tools import to_datetime
+from pandas.core.tools.datetimes import to_datetime
 
 from contextlib import contextmanager
 
@@ -88,7 +89,7 @@ def _is_sqlalchemy_connectable(con):
 
 
 def _convert_params(sql, params):
-    """convert sql and params args to DBAPI2.0 compliant format"""
+    """Convert SQL and params args to DBAPI2.0 compliant format."""
     args = [sql]
     if params is not None:
         if hasattr(params, 'keys'):  # test if params is a mapping
@@ -98,30 +99,30 @@ def _convert_params(sql, params):
     return args
 
 
-def _handle_date_column(col, format=None):
+def _handle_date_column(col, utc=None, format=None):
     if isinstance(format, dict):
         return to_datetime(col, errors='ignore', **format)
     else:
-        if format in ['D', 's', 'ms', 'us', 'ns']:
-            return to_datetime(col, errors='coerce', unit=format, utc=True)
-        elif (issubclass(col.dtype.type, np.floating) or
-              issubclass(col.dtype.type, np.integer)):
-            # parse dates as timestamp
-            format = 's' if format is None else format
-            return to_datetime(col, errors='coerce', unit=format, utc=True)
+        # Allow passing of formatting string for integers
+        # GH17855
+        if format is None and (issubclass(col.dtype.type, np.floating) or
+                               issubclass(col.dtype.type, np.integer)):
+            format = 's'
+        if format in ['D', 'd', 'h', 'm', 's', 'ms', 'us', 'ns']:
+            return to_datetime(col, errors='coerce', unit=format, utc=utc)
         elif is_datetime64tz_dtype(col):
             # coerce to UTC timezone
             # GH11216
             return (to_datetime(col, errors='coerce')
                     .astype('datetime64[ns, UTC]'))
         else:
-            return to_datetime(col, errors='coerce', format=format, utc=True)
+            return to_datetime(col, errors='coerce', format=format, utc=utc)
 
 
 def _parse_date_columns(data_frame, parse_dates):
     """
     Force non-datetime columns to be read as such.
-    Supports both string formatted and integer timestamp columns
+    Supports both string formatted and integer timestamp columns.
     """
     # handle non-list entries for parse_dates gracefully
     if parse_dates is True or parse_dates is None or parse_dates is False:
@@ -150,7 +151,7 @@ def _parse_date_columns(data_frame, parse_dates):
 
 def _wrap_result(data, columns, index_col=None, coerce_float=True,
                  parse_dates=None):
-    """Wrap result set of query in a DataFrame """
+    """Wrap result set of query in a DataFrame."""
 
     frame = DataFrame.from_records(data, columns=columns,
                                    coerce_float=coerce_float)
@@ -170,9 +171,9 @@ def execute(sql, con, cur=None, params=None):
     Parameters
     ----------
     sql : string
-        Query to be executed
+        SQL query to be executed.
     con : SQLAlchemy connectable(engine/connection) or sqlite3 connection
-        Using SQLAlchemy makes it possible to use any DB supported by that
+        Using SQLAlchemy makes it possible to use any DB supported by the
         library.
         If a DBAPI2 object, only sqlite3 is supported.
     cur : deprecated, cursor is obtained from connection, default: None
@@ -199,36 +200,36 @@ def read_sql_table(table_name, con, schema=None, index_col=None,
                    chunksize=None):
     """Read SQL database table into a DataFrame.
 
-    Given a table name and an SQLAlchemy connectable, returns a DataFrame.
+    Given a table name and a SQLAlchemy connectable, returns a DataFrame.
     This function does not support DBAPI connections.
 
     Parameters
     ----------
     table_name : string
-        Name of SQL table in database
+        Name of SQL table in database.
     con : SQLAlchemy connectable (or database string URI)
-        Sqlite DBAPI connection mode not supported
+        SQLite DBAPI connection mode not supported.
     schema : string, default None
         Name of SQL schema in database to query (if database flavor
-        supports this). If None, use default schema (default).
+        supports this). Uses default schema if None (default).
     index_col : string or list of strings, optional, default: None
-        Column(s) to set as index(MultiIndex)
+        Column(s) to set as index(MultiIndex).
     coerce_float : boolean, default True
-        Attempt to convert values to non-string, non-numeric objects (like
+        Attempts to convert values of non-string, non-numeric objects (like
         decimal.Decimal) to floating point. Can result in loss of Precision.
     parse_dates : list or dict, default: None
-        - List of column names to parse as dates
+        - List of column names to parse as dates.
         - Dict of ``{column_name: format string}`` where format string is
           strftime compatible in case of parsing string times or is one of
-          (D, s, ns, ms, us) in case of parsing integer timestamps
+          (D, s, ns, ms, us) in case of parsing integer timestamps.
         - Dict of ``{column_name: arg dict}``, where the arg dict corresponds
           to the keyword arguments of :func:`pandas.to_datetime`
           Especially useful with databases without native Datetime support,
-          such as SQLite
+          such as SQLite.
     columns : list, default: None
-        List of column names to select from sql table
+        List of column names to select from SQL table
     chunksize : int, default None
-        If specified, return an iterator where `chunksize` is the number of
+        If specified, returns an iterator where `chunksize` is the number of
         rows to include in each chunk.
 
     Returns
@@ -237,7 +238,7 @@ def read_sql_table(table_name, con, schema=None, index_col=None,
 
     Notes
     -----
-    Any datetime values with time zone information will be converted to UTC
+    Any datetime values with time zone information will be converted to UTC.
 
     See also
     --------
@@ -280,17 +281,17 @@ def read_sql_query(sql, con, index_col=None, coerce_float=True, params=None,
     Parameters
     ----------
     sql : string SQL query or SQLAlchemy Selectable (select or text object)
-        to be executed.
-    con : SQLAlchemy connectable(engine/connection) or database string URI
+        SQL query to be executed.
+    con : SQLAlchemy connectable(engine/connection), database string URI,
         or sqlite3 DBAPI2 connection
         Using SQLAlchemy makes it possible to use any DB supported by that
         library.
         If a DBAPI2 object, only sqlite3 is supported.
     index_col : string or list of strings, optional, default: None
-        Column(s) to set as index(MultiIndex)
+        Column(s) to set as index(MultiIndex).
     coerce_float : boolean, default True
-        Attempt to convert values to non-string, non-numeric objects (like
-        decimal.Decimal) to floating point, useful for SQL result sets
+        Attempts to convert values of non-string, non-numeric objects (like
+        decimal.Decimal) to floating point. Useful for SQL result sets.
     params : list, tuple or dict, optional, default: None
         List of parameters to pass to execute method.  The syntax used
         to pass parameters is database driver dependent. Check your
@@ -298,14 +299,14 @@ def read_sql_query(sql, con, index_col=None, coerce_float=True, params=None,
         described in PEP 249's paramstyle, is supported.
         Eg. for psycopg2, uses %(name)s so use params={'name' : 'value'}
     parse_dates : list or dict, default: None
-        - List of column names to parse as dates
+        - List of column names to parse as dates.
         - Dict of ``{column_name: format string}`` where format string is
-          strftime compatible in case of parsing string times or is one of
-          (D, s, ns, ms, us) in case of parsing integer timestamps
+          strftime compatible in case of parsing string times, or is one of
+          (D, s, ns, ms, us) in case of parsing integer timestamps.
         - Dict of ``{column_name: arg dict}``, where the arg dict corresponds
           to the keyword arguments of :func:`pandas.to_datetime`
           Especially useful with databases without native Datetime support,
-          such as SQLite
+          such as SQLite.
     chunksize : int, default None
         If specified, return an iterator where `chunksize` is the number of
         rows to include in each chunk.
@@ -317,11 +318,11 @@ def read_sql_query(sql, con, index_col=None, coerce_float=True, params=None,
     Notes
     -----
     Any datetime values with time zone information parsed via the `parse_dates`
-    parameter will be converted to UTC
+    parameter will be converted to UTC.
 
     See also
     --------
-    read_sql_table : Read SQL database table into a DataFrame
+    read_sql_table : Read SQL database table into a DataFrame.
     read_sql
 
     """
@@ -338,18 +339,18 @@ def read_sql(sql, con, index_col=None, coerce_float=True, params=None,
 
     Parameters
     ----------
-    sql : string SQL query or SQLAlchemy Selectable (select or text object)
-        to be executed, or database table name.
+    sql : string or SQLAlchemy Selectable (select or text object)
+        SQL query to be executed.
     con : SQLAlchemy connectable(engine/connection) or database string URI
         or DBAPI2 connection (fallback mode)
         Using SQLAlchemy makes it possible to use any DB supported by that
         library.
         If a DBAPI2 object, only sqlite3 is supported.
     index_col : string or list of strings, optional, default: None
-        Column(s) to set as index(MultiIndex)
+        Column(s) to set as index(MultiIndex).
     coerce_float : boolean, default True
-        Attempt to convert values to non-string, non-numeric objects (like
-        decimal.Decimal) to floating point, useful for SQL result sets
+        Attempts to convert values of non-string, non-numeric objects (like
+        decimal.Decimal) to floating point, useful for SQL result sets.
     params : list, tuple or dict, optional, default: None
         List of parameters to pass to execute method.  The syntax used
         to pass parameters is database driver dependent. Check your
@@ -357,16 +358,16 @@ def read_sql(sql, con, index_col=None, coerce_float=True, params=None,
         described in PEP 249's paramstyle, is supported.
         Eg. for psycopg2, uses %(name)s so use params={'name' : 'value'}
     parse_dates : list or dict, default: None
-        - List of column names to parse as dates
+        - List of column names to parse as dates.
         - Dict of ``{column_name: format string}`` where format string is
-          strftime compatible in case of parsing string times or is one of
-          (D, s, ns, ms, us) in case of parsing integer timestamps
+          strftime compatible in case of parsing string times, or is one of
+          (D, s, ns, ms, us) in case of parsing integer timestamps.
         - Dict of ``{column_name: arg dict}``, where the arg dict corresponds
           to the keyword arguments of :func:`pandas.to_datetime`
           Especially useful with databases without native Datetime support,
-          such as SQLite
+          such as SQLite.
     columns : list, default: None
-        List of column names to select from sql table (only used when reading
+        List of column names to select from SQL table (only used when reading
         a table).
     chunksize : int, default None
         If specified, return an iterator where `chunksize` is the
@@ -381,13 +382,13 @@ def read_sql(sql, con, index_col=None, coerce_float=True, params=None,
     This function is a convenience wrapper around ``read_sql_table`` and
     ``read_sql_query`` (and for backward compatibility) and will delegate
     to the specific function depending on the provided input (database
-    table name or sql query).  The delegated function might have more specific
+    table name or SQL query).  The delegated function might have more specific
     notes about their functionality not listed here.
 
     See also
     --------
-    read_sql_table : Read SQL database table into a DataFrame
-    read_sql_query : Read SQL query into a DataFrame
+    read_sql_table : Read SQL database table into a DataFrame.
+    read_sql_query : Read SQL query into a DataFrame.
 
     """
     pandas_sql = pandasSQL_builder(con)
@@ -424,14 +425,16 @@ def to_sql(frame, name, con, flavor=None, schema=None, if_exists='fail',
     ----------
     frame : DataFrame
     name : string
-        Name of SQL table
+        Name of SQL table.
     con : SQLAlchemy connectable(engine/connection) or database string URI
         or sqlite3 DBAPI2 connection
         Using SQLAlchemy makes it possible to use any DB supported by that
         library.
         If a DBAPI2 object, only sqlite3 is supported.
     flavor : 'sqlite', default None
-        DEPRECATED: this parameter will be removed in a future version
+        .. deprecated:: 0.19.0
+           'sqlite' is the only supported option if SQLAlchemy is not
+           used.
     schema : string, default None
         Name of SQL schema in database to write to (if database flavor
         supports this). If None, use default schema (default).
@@ -440,7 +443,7 @@ def to_sql(frame, name, con, flavor=None, schema=None, if_exists='fail',
         - replace: If table exists, drop it, recreate it, and insert data.
         - append: If table exists, insert data. Create if does not exist.
     index : boolean, default True
-        Write DataFrame index as a column
+        Write DataFrame index as a column.
     index_label : string or sequence, default None
         Column label for index column(s). If None is given (default) and
         `index` is True, then the index names are used.
@@ -477,13 +480,15 @@ def has_table(table_name, con, flavor=None, schema=None):
     Parameters
     ----------
     table_name: string
-        Name of SQL table
+        Name of SQL table.
     con: SQLAlchemy connectable(engine/connection) or sqlite3 DBAPI2 connection
         Using SQLAlchemy makes it possible to use any DB supported by that
         library.
         If a DBAPI2 object, only sqlite3 is supported.
     flavor : 'sqlite', default None
-        DEPRECATED: this parameter will be removed in a future version
+        .. deprecated:: 0.19.0
+           'sqlite' is the only supported option if SQLAlchemy is not
+           installed.
     schema : string, default None
         Name of SQL schema in database to write to (if database flavor supports
         this). If None, use default schema (default).
@@ -495,22 +500,24 @@ def has_table(table_name, con, flavor=None, schema=None):
     pandas_sql = pandasSQL_builder(con, flavor=flavor, schema=schema)
     return pandas_sql.has_table(table_name)
 
+
 table_exists = has_table
 
 
 def _engine_builder(con):
     """
     Returns a SQLAlchemy engine from a URI (if con is a string)
-    else it just return con without modifying it
+    else it just return con without modifying it.
     """
     global _SQLALCHEMY_INSTALLED
     if isinstance(con, string_types):
         try:
             import sqlalchemy
-            con = sqlalchemy.create_engine(con)
-            return con
         except ImportError:
             _SQLALCHEMY_INSTALLED = False
+        else:
+            con = sqlalchemy.create_engine(con)
+            return con
 
     return con
 
@@ -519,7 +526,7 @@ def pandasSQL_builder(con, flavor=None, schema=None, meta=None,
                       is_cursor=False):
     """
     Convenience function to return the correct PandasSQL subclass based on the
-    provided parameters
+    provided parameters.
     """
     _validate_flavor_parameter(flavor)
 
@@ -538,7 +545,7 @@ class SQLTable(PandasObject):
     """
     For mapping Pandas tables to SQL tables.
     Uses fact that table is reflected by SQLAlchemy to
-    do better type convertions.
+    do better type conversions.
     Also holds various flags needed to avoid having to
     pass them between functions all the time.
     """
@@ -625,7 +632,7 @@ class SQLTable(PandasObject):
 
             # replace NaN with None
             if b._can_hold_na:
-                mask = isnull(d)
+                mask = isna(d)
                 d[mask] = None
 
             for col_loc, col in zip(b.mgr_locs, d):
@@ -664,7 +671,7 @@ class SQLTable(PandasObject):
 
     def _query_iterator(self, result, chunksize, columns, coerce_float=True,
                         parse_dates=None):
-        """Return generator through chunked result set"""
+        """Return generator through chunked result set."""
 
         while True:
             data = result.fetchmany(chunksize)
@@ -747,8 +754,9 @@ class SQLTable(PandasObject):
         if self.index is not None:
             for i, idx_label in enumerate(self.index):
                 idx_type = dtype_mapper(
-                    self.frame.index.get_level_values(i))
-                column_names_and_types.append((idx_label, idx_type, True))
+                    self.frame.index._get_level_values(i))
+                column_names_and_types.append((text_type(idx_label),
+                                              idx_type, True))
 
         column_names_and_types += [
             (text_type(self.frame.columns[i]),
@@ -795,7 +803,7 @@ class SQLTable(PandasObject):
         all Nones with false. Therefore only convert bool if there are no
         NA values.
         Datetimes should already be converted to np.datetime64 if supported,
-        but here we also force conversion if required
+        but here we also force conversion if required.
         """
         # handle non-list entries for parse_dates gracefully
         if parse_dates is True or parse_dates is None or parse_dates is False:
@@ -813,8 +821,9 @@ class SQLTable(PandasObject):
 
                 if (col_type is datetime or col_type is date or
                         col_type is DatetimeTZDtype):
-                    self.frame[col_name] = _handle_date_column(df_col)
-
+                    # Convert tz-aware Datetime SQL columns to UTC
+                    utc = col_type is DatetimeTZDtype
+                    self.frame[col_name] = _handle_date_column(df_col, utc=utc)
                 elif col_type is float:
                     # floats support NA, can always convert!
                     self.frame[col_name] = df_col.astype(col_type, copy=False)
@@ -837,7 +846,7 @@ class SQLTable(PandasObject):
             except KeyError:
                 pass  # this column not in results
 
-    def _get_notnull_col_dtype(self, col):
+    def _get_notna_col_dtype(self, col):
         """
         Infer datatype of the Series col.  In case the dtype of col is 'object'
         and it contains NA values, this infers the datatype of the not-NA
@@ -845,9 +854,9 @@ class SQLTable(PandasObject):
         """
         col_for_inference = col
         if col.dtype == 'object':
-            notnulldata = col[~isnull(col)]
-            if len(notnulldata):
-                col_for_inference = notnulldata
+            notnadata = col[~isna(col)]
+            if len(notnadata):
+                col_for_inference = notnadata
 
         return lib.infer_dtype(col_for_inference)
 
@@ -857,7 +866,7 @@ class SQLTable(PandasObject):
         if col.name in dtype:
             return self.dtype[col.name]
 
-        col_type = self._get_notnull_col_dtype(col)
+        col_type = self._get_notna_col_dtype(col)
 
         from sqlalchemy.types import (BigInteger, Integer, Float,
                                       Text, Boolean,
@@ -921,7 +930,7 @@ class SQLTable(PandasObject):
 
 class PandasSQL(PandasObject):
     """
-    Subclasses Should define read_sql and to_sql
+    Subclasses Should define read_sql and to_sql.
     """
 
     def read_sql(self, *args, **kwargs):
@@ -935,8 +944,8 @@ class PandasSQL(PandasObject):
 
 class SQLDatabase(PandasSQL):
     """
-    This class enables convertion between DataFrame and SQL databases
-    using SQLAlchemy to handle DataBase abstraction
+    This class enables conversion between DataFrame and SQL databases
+    using SQLAlchemy to handle DataBase abstraction.
 
     Parameters
     ----------
@@ -981,28 +990,28 @@ class SQLDatabase(PandasSQL):
         Parameters
         ----------
         table_name : string
-            Name of SQL table in database
+            Name of SQL table in database.
         index_col : string, optional, default: None
-            Column to set as index
+            Column to set as index.
         coerce_float : boolean, default True
-            Attempt to convert values to non-string, non-numeric objects
+            Attempts to convert values of non-string, non-numeric objects
             (like decimal.Decimal) to floating point. This can result in
             loss of precision.
         parse_dates : list or dict, default: None
-            - List of column names to parse as dates
+            - List of column names to parse as dates.
             - Dict of ``{column_name: format string}`` where format string is
-              strftime compatible in case of parsing string times or is one of
-              (D, s, ns, ms, us) in case of parsing integer timestamps
+              strftime compatible in case of parsing string times, or is one of
+              (D, s, ns, ms, us) in case of parsing integer timestamps.
             - Dict of ``{column_name: arg}``, where the arg corresponds
               to the keyword arguments of :func:`pandas.to_datetime`.
               Especially useful with databases without native Datetime support,
-              such as SQLite
+              such as SQLite.
         columns : list, default: None
-            List of column names to select from sql table
+            List of column names to select from SQL table.
         schema : string, default None
             Name of SQL schema in database to query (if database flavor
             supports this).  If specified, this overwrites the default
-            schema of the SQLDatabase object.
+            schema of the SQL database object.
         chunksize : int, default None
             If specified, return an iterator where `chunksize` is the number
             of rows to include in each chunk.
@@ -1043,12 +1052,12 @@ class SQLDatabase(PandasSQL):
         Parameters
         ----------
         sql : string
-            SQL query to be executed
+            SQL query to be executed.
         index_col : string, optional, default: None
             Column name to use as index for the returned DataFrame object.
         coerce_float : boolean, default True
-            Attempt to convert values to non-string, non-numeric objects (like
-            decimal.Decimal) to floating point, useful for SQL result sets
+            Attempt to convert values of non-string, non-numeric objects (like
+            decimal.Decimal) to floating point, useful for SQL result sets.
         params : list, tuple or dict, optional, default: None
             List of parameters to pass to execute method.  The syntax used
             to pass parameters is database driver dependent. Check your
@@ -1056,14 +1065,14 @@ class SQLDatabase(PandasSQL):
             described in PEP 249's paramstyle, is supported.
             Eg. for psycopg2, uses %(name)s so use params={'name' : 'value'}
         parse_dates : list or dict, default: None
-            - List of column names to parse as dates
+            - List of column names to parse as dates.
             - Dict of ``{column_name: format string}`` where format string is
-              strftime compatible in case of parsing string times or is one of
-              (D, s, ns, ms, us) in case of parsing integer timestamps
+              strftime compatible in case of parsing string times, or is one of
+              (D, s, ns, ms, us) in case of parsing integer timestamps.
             - Dict of ``{column_name: arg dict}``, where the arg dict
               corresponds to the keyword arguments of
               :func:`pandas.to_datetime` Especially useful with databases
-              without native Datetime support, such as SQLite
+              without native Datetime support, such as SQLite.
         chunksize : int, default None
             If specified, return an iterator where `chunksize` is the number
             of rows to include in each chunk.
@@ -1106,13 +1115,13 @@ class SQLDatabase(PandasSQL):
         ----------
         frame : DataFrame
         name : string
-            Name of SQL table
+            Name of SQL table.
         if_exists : {'fail', 'replace', 'append'}, default 'fail'
             - fail: If table exists, do nothing.
             - replace: If table exists, drop it, recreate it, and insert data.
             - append: If table exists, insert data. Create if does not exist.
         index : boolean, default True
-            Write DataFrame index as a column
+            Write DataFrame index as a column.
         index_label : string or sequence, default None
             Column label for index column(s). If None is given (default) and
             `index` is True, then the index names are used.
@@ -1218,7 +1227,7 @@ _SQL_TYPES = {
 
 def _get_unicode_name(name):
     try:
-        uname = name.encode("utf-8", "strict").decode("utf-8")
+        uname = text_type(name).encode("utf-8", "strict").decode("utf-8")
     except UnicodeError:
         raise ValueError("Cannot convert identifier to UTF-8: '%s'" % name)
     return uname
@@ -1291,9 +1300,9 @@ class SQLiteTable(SQLTable):
 
     def _create_table_setup(self):
         """
-        Return a list of SQL statement that create a table reflecting the
+        Return a list of SQL statements that creates a table reflecting the
         structure of a DataFrame.  The first entry will be a CREATE TABLE
-        statement while the rest will be CREATE INDEX statements
+        statement while the rest will be CREATE INDEX statements.
         """
         column_names_and_types = \
             self._get_column_names_and_types(self._sql_type_name)
@@ -1337,7 +1346,7 @@ class SQLiteTable(SQLTable):
         if col.name in dtype:
             return dtype[col.name]
 
-        col_type = self._get_notnull_col_dtype(col)
+        col_type = self._get_notna_col_dtype(col)
         if col_type == 'timedelta64':
             warnings.warn("the 'timedelta' type is not supported, and will be "
                           "written as integer values (ns frequency) to the "
@@ -1361,8 +1370,8 @@ class SQLiteTable(SQLTable):
 
 class SQLiteDatabase(PandasSQL):
     """
-    Version of SQLDatabase to support sqlite connections (fallback without
-    sqlalchemy). This should only be used internally.
+    Version of SQLDatabase to support SQLite connections (fallback without
+    SQLAlchemy). This should only be used internally.
 
     Parameters
     ----------
@@ -1463,11 +1472,12 @@ class SQLiteDatabase(PandasSQL):
         Parameters
         ----------
         frame: DataFrame
-        name: name of SQL table
+        name: string
+            Name of SQL table.
         if_exists: {'fail', 'replace', 'append'}, default 'fail'
             fail: If table exists, do nothing.
             replace: If table exists, drop it, recreate it, and insert data.
-            append: If table exists, insert data. Create if does not exist.
+            append: If table exists, insert data. Create if it does not exist.
         index : boolean, default True
             Write DataFrame index as a column
         index_label : string or sequence, default None
@@ -1541,7 +1551,9 @@ def get_schema(frame, name, flavor=None, keys=None, con=None, dtype=None):
         library, default: None
         If a DBAPI2 object, only sqlite3 is supported.
     flavor : 'sqlite', default None
-        DEPRECATED: this parameter will be removed in a future version
+        .. deprecated:: 0.19.0
+           'sqlite' is the only supported option if SQLAlchemy is not
+           installed.
     dtype : dict of column name to SQL type, default None
         Optional specifying the datatype for columns. The SQL type should
         be a SQLAlchemy type, or a string for sqlite3 fallback connection.
